import os
import requests

class BatMusic:
    def __init__(self, domain: str = "http://batbyte.duckdns.org:5006"):
        self.domain = domain.rstrip("/")
        self.headers = {"User-Agent": "BatMusic Client"}
        self.download_dir = "downloads"
        os.makedirs(self.download_dir, exist_ok=True)

    def _save_file(self, file_url: str):
        try:
            filename = file_url.split("?fname=")[-1].replace(" ", "_")
            local_path = os.path.join(self.download_dir, filename)
            response = requests.get(file_url, stream=True)
            with open(local_path, "wb") as file:
                for chunk in response.iter_content(chunk_size=8192):
                    if chunk:
                        file.write(chunk)
            return local_path
        except Exception as e:
            return f"Download error: {e}"

    # ---- Spotify ----
    def search_spotify(self, query: str,limit : int =10):
        url = f"{self.domain}/spotify/search"
        response = requests.get(url, params={"q": query, "limit": limit}, headers=self.headers)
        return response.json()

    def download_spotify(self, url: str):
        api_url = f"{self.domain}/spotify/download"
        response = requests.get(api_url, params={"url": url}, headers=self.headers)
        data = response.json()
        if data.get("status") != "success":
            return data
        path = self._save_file(data.get("url"))
        data["path"] = path
        data.pop("url", None)
        return data
    # ---- Apple Music ----
    def search_apple(self, query: str):
        url = f"{self.domain}/apple/search"
        response = requests.get(url, params={"q": query}, headers=self.headers)
        return response.json()

    def download_apple(self, url: str):
        api_url = f"{self.domain}/apple/download"
        response = requests.get(api_url, params={"url": url}, headers=self.headers)
        data = response.json()
        if data.get("status") != "success":
            return data
        path = self._save_file(data.get("url"))
        data["path"] = path
        data.pop("url", None)
        return data